#
# spec file for package python-aiosqlite
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2019 Matthias Fehring <buschmann23@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-aiosqlite
Version:        0.21.0
Release:        1.3
Summary:        AsyncIO Bridge to the Standard Python sqlite3 Module
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jreese/aiosqlite
Source:         https://files.pythonhosted.org/packages/source/a/aiosqlite/aiosqlite-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{pythons}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python
BuildArch:      noarch
%python_subpackages

%description
aiosqlite replicates the standard sqlite3 module, but with async versions of all
the standard connection and cursor methods, and context managers for
automatically closing connections.

%prep
%autosetup -p1 -n aiosqlite-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/aiosqlite
%{python_sitelib}/aiosqlite-%{version}.dist-info

%changelog
* Mon Feb 24 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.21.0
  * Fix: close connection correctly when BaseException raised
    in connection (#317)
  * Metadata improvements
  * Tested and supported on Python 3.13
  * Drop support for Python 3.8
  * Drop testing on PyPy
- Drop CHANGELOG.md from %%files section, removed upstream
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.20.0:
  * Connection `.close()` method is now idempotent
  * Performance improvements in connection thread and event loop
  * Updated contributor guide
  * Tested on Python 3.12
  * Dropped support for Python 3.7
* Sun Jun 11 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.19.0
  * Add support for setting cursor `row_factory` (#229)
  * Dropped unused compatibility shims for 3.5 and 3.6
  * Deprecated: Python 3.7 support will be dropped in v0.20.0
- Release 0.18.0
  * Added support for `paramstyle` (#197)
  * Better type hints for `isolation_level` (#172) and
    `text_factory` (#179)
  * Use stdlib typing module when possible (#114)
  * Replace aiounittest with stdlib on 3.8+
  * Docmentation improvements (#108)
  * Dropped support for Python 3.7, added support for Python 3.10
    and 3.11 (#208)
- Drop stdlib-typing_extensions.patch
  * the upstream issue was accepted and the module was removed
    but later introduced for Python < 3.8 due to a different case
* Fri May 14 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.17.0:
  - Connection objects now raise ValueError when closed and a
    command is executed (#79)
  - Fix documented examples in readme (#104)
  - Reduce logging severity for exceptions (#93)
  - Stop logging result objects; they can be big (#102)
- Add stdlib-typing_extensions.patch to avoid necessity for BR
  python-typing_extensions (gh#omnilib/aiosqlite#114).
* Sat Nov 28 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.16.0
* Tue Apr 21 2020 Matthias Fehring <buschmann23@opensuse.org>
- update to version 0.12.0
  * Add support for custom functions (#58)
  * Official support for Python 3.8
- update to version 0.11.0
  * Added support for set_progress_handler (#49)
  * Improved and updated documentation
- spec file changes
  * add pythons to the build requires
  * add python to the requires
* Tue Jul  2 2019 Matthias Fehring <buschmann23@opensuse.org>
- initial package version 0.10.0
